DROP TABLE CUSTOSUP_TMP
/
CREATE TABLE CUSTOSUP_TMP
 (CDFILIAL     VARCHAR2(4),
  CDFILCENTCMP VARCHAR2(4),
  NRSEQPRELIST VARCHAR2(10),
  DTINIVALITM  DATE,
  DTFINVALITM  DATE,
  CDPRODESTO   VARCHAR2(10),
  NRCOLEPRECO  VARCHAR2(10),
  CDREGIAO     VARCHAR2(3),
  CDFORNECED   VARCHAR2(21),
  CDPRODUTO    VARCHAR2(10),
  CDMARCA      VARCHAR2(5),
  VRPRECOUN    FLOAT,
  VRPRECECO    FLOAT,
  VRPRECOPI    FLOAT)
/
CREATE INDEX CUSTOSUP_TMP_01 ON CUSTOSUP_TMP(CDFILCENTCMP, NRSEQPRELIST)
/
DROP TABLE CUSTOSUPACOR_TMP
/
CREATE TABLE CUSTOSUPACOR_TMP
 (CDFILIAL     VARCHAR2(4),
  CDFILCENTCMP VARCHAR2(4),
  NRSEQPRELIST VARCHAR2(10),
  DTINIVALITM  DATE,
  DTFINVALITM  DATE,
  CDPRODESTO   VARCHAR2(10),
  NRCOLEPRECO  VARCHAR2(10),
  CDREGIAO     VARCHAR2(3),
  CDFORNECED   VARCHAR2(21),
  CDPRODUTO    VARCHAR2(10),
  CDMARCA      VARCHAR2(5),
  VRPRECOUN    FLOAT,
  VRPRECECO    FLOAT,
  VRPRECOPI    FLOAT)
/
CREATE INDEX CUSTOSUPACOR_TMP_01 ON CUSTOSUPACOR_TMP(CDFILCENTCMP, NRSEQPRELIST)
/

/* Sistemas Integrados TEKNISA
   Compras e Suprimentos

Nome: 8640_SUPSTPO.sql

Descrio:
Atualiza o preo do produto da lista de preo na CUSTOSUP considerando
particularidades e produto preferencial.

Criao:
02/12/2003 Adriano de Arajo
*/

CREATE OR REPLACE
PROCEDURE LISPREC_UPPRODFILI
  (P_CDFILIAL     IN ITMPREVLIST.CDFILIAL%TYPE,
   P_NRSEQPRELIST IN ITMPREVLIST.NRSEQPRELIST%TYPE,
   P_ATUCUSTO     IN VARCHAR2 DEFAULT 'N',
   P_CDFILCUSTO   IN FILIAL.CDFILIAL%TYPE DEFAULT NULL) IS

   V_COUNT        INT;
   V_VRPRECULISM1 FLOAT;
   V_VRPRECULISM2 FLOAT;
   V_IDUTCUSLIPR  VARCHAR2(1);

   V_POSMINPRECO  INT;
   V_POSMINPREPI  INT;

   V_MINPRECO     FLOAT;
   V_VRIMPITM     FLOAT;
   V_NRCOLEPRECO  ITEMCOLE.NRCOLEPRECO%TYPE;
   V_CDREGIAO     ITEMCOLE.CDREGIAO%TYPE;
   V_CDFORNECED   ITEMCOLE.CDFORNECED%TYPE;
   V_CDPRODUTO    ITEMCOLE.CDPRODUTO%TYPE;
   V_CDMARCA      ITEMCOLE.CDMARCA%TYPE;

   V_IDTIPOAPUR   PARASUPRI.IDTIPOAPUR%TYPE;

   V_DTINIVALLIST PREVLISTA.DTINIVALLIST%TYPE;

   V_MULTIPLO     INT;
   V_MASCARA      VARCHAR2(255);

   V_CONT_COMMIT NUMBER := 0;
   V_QTDE_COMMIT NUMBER := 1000;

   V_COUNT_AUX    FLOAT;
   V_VRFATOCONV   FLOAT;

BEGIN
   V_MASCARA    := '00000000000000000000000';
   V_MULTIPLO   := 1000000;
   V_VRFATOCONV := 1;

   SELECT
      MAX(IDTIPOAPUR) INTO V_IDTIPOAPUR
   FROM
      PARASUPRI
   WHERE
      CDFILIAL = P_CDFILIAL;

   SELECT
     MAX(DTINIVALLIST) INTO V_DTINIVALLIST
   FROM
     PREVLISTA
   WHERE
     CDFILIAL     = P_CDFILIAL AND
     NRSEQPRELIST = P_NRSEQPRELIST;

   SELECT
      NVL(MAX(IDUTTPCUSTO), 'N')
   INTO
      V_IDUTCUSLIPR
   FROM
      TIPOCUSTO
   WHERE
      CDTIPOCUSTO = '10';

   V_CONT_COMMIT := 0;

   FOR C_VERIF_CUSTO IN
      (SELECT
           CUSTOSUP.ROWID,
           CUSTOSUP.CDFILIAL,
           CUSTOSUP.CDPRODUTO,
           CUSTOSUP.DTCUSTOSUP
       FROM
          CUSTOSUP,
          COLETAPR,
          ITEMCOLE,
          PREVLISTA
       WHERE
          PREVLISTA.CDFILIAL      = P_CDFILIAL             AND
          PREVLISTA.NRSEQPRELIST  = P_NRSEQPRELIST         AND
          PREVLISTA.DTINIVALLIST <= ITEMCOLE.DTINIVALITM   AND
          PREVLISTA.DTFINVALLIST >= ITEMCOLE.DTFINVALITM   AND
          ITEMCOLE.CDFILIAL       = PREVLISTA.CDFILIAL     AND
          ITEMCOLE.CDFILIAL       = COLETAPR.CDFILIAL      AND
          ITEMCOLE.NRCOLEPRECO    = COLETAPR.NRCOLEPRECO   AND
          COLETAPR.CDOPERADOR     = PREVLISTA.CDOPERADOR   AND
          ITEMCOLE.CDFILIAL       = CUSTOSUP.CDFILCOTLIST  AND
          ITEMCOLE.NRCOLEPRECO    = CUSTOSUP.NRCOLEPRLIST  AND
          ITEMCOLE.CDMARCA        = CUSTOSUP.CDMARCALIST   AND
          ITEMCOLE.CDREGIAO       = CUSTOSUP.CDREGIAOLIST  AND
          ITEMCOLE.CDFORNECED     = CUSTOSUP.CDFORNECLIST  AND
          ITEMCOLE.CDPRODUTO      = CUSTOSUP.CDPRODLIST    AND
          CUSTOSUP.VRPRCUSTOAF IS NULL                    AND
          (EXISTS(SELECT
                     '1'
                  FROM
                     FORNECEDOR
                  WHERE
                     FORNECEDOR.CDFORNECED = CUSTOSUP.CDFORNECLIST AND
                     NVL(FORNECEDOR.IDSITUCADA, 'A') <> 'A'
                  ) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     FORNECEDOR
                  WHERE
                     FORNECEDOR.CDFORNECED = CUSTOSUP.CDFORNECLIST AND
                     NVL(FORNECEDOR.IDTIPOFORN, 'N') <> 'N'
                  ) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     REFORFIL
                  WHERE
                     (REFORFIL.CDFILIAL   = CUSTOSUP.CDFILIAL)     AND
                     (REFORFIL.CDFORNECED = CUSTOSUP.CDFORNECLIST) AND
                     (REFORFIL.CDPERIENTR IS NULL)
                  ) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     REFOREG
                  WHERE
                    REFOREG.CDREGIAO   = CUSTOSUP.CDREGIAOLIST AND
                    REFOREG.CDFORNECED = CUSTOSUP.CDFORNECLIST
                  ) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     QFOPRODFORN,
                     PARASUPRI
                  WHERE
                     (PARASUPRI.CDFILIAL     = P_CDFILIAL)            AND
                     (QFOPRODFORN.CDPRODUTO  = CUSTOSUP.CDPRODUTO)    AND
                     (QFOPRODFORN.CDFORNECED = CUSTOSUP.CDFORNECLIST) AND
                     ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOPRODFORN.DTVALPRFORN))))) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     QFOMARPROD,
                     PARASUPRI
                  WHERE
                     (PARASUPRI.CDFILIAL   = P_CDFILIAL)           AND
                     (QFOMARPROD.CDPRODUTO = CUSTOSUP.CDPRODUTO)   AND
                     (QFOMARPROD.CDMARCA   = CUSTOSUP.CDMARCALIST) AND
                     ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOMARPROD.DTVALAPROVA))))) OR
           NOT EXISTS(SELECT
                        '1'
                     FROM
                        QFOMARPROD
                     WHERE
                        (QFOMARPROD.CDPRODUTO = CUSTOSUP.CDPRODUTO) AND
                        (QFOMARPROD.CDMARCA   = CUSTOSUP.CDMARCALIST)

                     UNION

                     SELECT
                        '1'
                     FROM
                        PARASUPRI
                     WHERE
                        (PARASUPRI.CDFILIAL    = P_CDFILIAL) AND
                        (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL)
                      ) OR
           EXISTS(SELECT
                     '1'
                  FROM
                     QUALIFICACAO,
                     FORNECEDOR,
                     PARASUPRI
                  WHERE
                     (FORNECEDOR.CDFORNECED     = CUSTOSUP.CDFORNECLIST) AND
                     (QUALIFICACAO.CDQUALIF     = FORNECEDOR.CDQUALIF)   AND
                     (PARASUPRI.CDFILIAL        = P_CDFILIAL)            AND
                     (FORNECEDOR.IDFORNAUTO     = 'N')                   AND
                     ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > FORNECEDOR.DTVALQUALIF) OR (PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(FORNECEDOR.DTVALQUALIF))))) OR
           ((NOT EXISTS (SELECT
                           '1'
                        FROM
                           PARTFILI
                        WHERE
                           (PARTFILI.CDFILIAL  = CUSTOSUP.CDFILIAL)      AND
                           (PARTFILI.CDPRODUTO = CUSTOSUP.CDPRODUTO)     AND
                           (PARTFILI.CDTIPPART IN ('1', '2'))            AND
                           (PARTFILI.CDMARCA   = CUSTOSUP.CDMARCALIST)))

            AND (NOT EXISTS (SELECT
                                '1'
                             FROM
                                PARTFILI
                             WHERE
                                (PARTFILI.CDFILIAL   = CUSTOSUP.CDFILIAL)   AND
                                (PARTFILI.CDPRODUTO  = CUSTOSUP.CDPRODUTO)  AND
                                (PARTFILI.CDTIPPART  IN ('4', '5'))         AND
                                (PARTFILI.CDFORNECED = CUSTOSUP.CDFORNECLIST)))

            AND (NOT EXISTS (SELECT
                                '1'
                             FROM
                                PARTFILI
                             WHERE
                                (PARTFILI.CDFILIAL   = CUSTOSUP.CDFILIAL)      AND
                                (PARTFILI.CDPRODUTO  = CUSTOSUP.CDPRODUTO)     AND
                                (PARTFILI.CDTIPPART  IN ('7', '8'))            AND
                                (PARTFILI.CDMARCA    = CUSTOSUP.CDMARCALIST)   AND
                                (PARTFILI.CDFORNECED = CUSTOSUP.CDFORNECLIST)))

            AND (NOT EXISTS (SELECT
                                '1'
                             FROM
                                PARTFILI
                             WHERE
                                (PARTFILI.CDFILIAL  = CUSTOSUP.CDFILIAL)   AND
                                (PARTFILI.CDPRODUTO = CUSTOSUP.CDPRODUTO)  AND
                                (PARTFILI.CDTIPPART  IN ('3','6','9'))))

            AND (EXISTS (SELECT
                            '1'
                         FROM
                            PARTFILI
                         WHERE
                            (PARTFILI.CDFILIAL  = CUSTOSUP.CDFILIAL) AND
                            (PARTFILI.CDPRODUTO = CUSTOSUP.CDPRODUTO)))
           ) OR
           EXISTS (SELECT
                      '1'
                   FROM
                      PARTFILI
                   WHERE
                      (CDFILIAL  = CUSTOSUP.CDFILIAL)     AND
                      (CDPRODUTO = CUSTOSUP.CDPRODUTO)    AND
                      (CDTIPPART = '3')                   AND
                      (CDMARCA   = CUSTOSUP.CDMARCALIST)) OR
           EXISTS (SELECT
                      '1'
                   FROM
                      PARTFILI
                   WHERE
                      (CDFILIAL   = CUSTOSUP.CDFILIAL)  AND
                      (CDPRODUTO  = CUSTOSUP.CDPRODUTO) AND
                      (CDTIPPART  = '6')                AND
                      (CDFORNECED = CUSTOSUP.CDFORNECLIST)) OR
           EXISTS (SELECT
                      '1'
                   FROM
                      PARTFILI
                   WHERE
                      (CDFILIAL   = CUSTOSUP.CDFILIAL)      AND
                      (CDPRODUTO  = CUSTOSUP.CDPRODUTO)     AND
                      (CDTIPPART  = '9')                    AND
                      (CDMARCA    = CUSTOSUP.CDMARCALIST)   AND
                      (CDFORNECED = CUSTOSUP.CDFORNECLIST))
           )
        )
   LOOP
      DELETE FROM CUSTOSUP
      WHERE
        C_VERIF_CUSTO.CDFILIAL   = CUSTOSUP.CDFILIALORIG AND
        C_VERIF_CUSTO.CDPRODUTO  = CUSTOSUP.CDPRODORIG   AND
        C_VERIF_CUSTO.DTCUSTOSUP = CUSTOSUP.DTCUSTSUPORI;

      DELETE FROM CUSTOSUP
      WHERE C_VERIF_CUSTO.ROWID = CUSTOSUP.ROWID;
   END LOOP;
   COMMIT;

   /* Cursor: C_DELCUSTACOR

      Tratamento dos custos de lista de preos da qual a cotao de acordo
      no mais existe. Os campos da cotao de acordo sero limpos e o valor
      do custo ser substitudo pelo valor da lista(atravs do campo VRHISPRLISTP),
      se no houver os campos da lista e nem custo de AF, o registro ser excludo.
   */
   FOR C_DELCUSTACOR IN
     (SELECT
         CUSTOSUP.CDFILIAL,
         CUSTOSUP.CDPRODUTO,
         CUSTOSUP.DTCUSTOSUP,
         CUSTOSUP.NRCOLEPRLIST,
         CUSTOSUP.VRPRCUSTOAF,
         CUSTOSUP.CDPRODACOR
      FROM
         CUSTOSUP
      WHERE
         (CUSTOSUP.CDFILIAL   = NVL(P_CDFILCUSTO, CUSTOSUP.CDFILIAL)) AND
         (CUSTOSUP.DTCUSTOSUP >= V_DTINIVALLIST)                      AND
         (CUSTOSUP.IDCUSLISTINF <> 'S')                               AND
         (CUSTOSUP.CDFILCOTACOR IS NOT NULL)                          AND
         NOT EXISTS
           (SELECT
               NRCOLEPRECO
            FROM
               ITEMCOLE
            WHERE
               (ITEMCOLE.CDFILIAL    = CUSTOSUP.CDFILCOTACOR) AND
               (ITEMCOLE.NRCOLEPRECO = CUSTOSUP.NRCOLEPRACOR) AND
               (ITEMCOLE.CDMARCA     = CUSTOSUP.CDMARCAACOR)  AND
               (ITEMCOLE.CDREGIAO    = CUSTOSUP.CDREGIAOACOR) AND
               (ITEMCOLE.CDFORNECED  = CUSTOSUP.CDFORNECACOR) AND
               (ITEMCOLE.CDPRODUTO   = CUSTOSUP.CDPRODACOR) ) )
   LOOP
      IF (C_DELCUSTACOR.NRCOLEPRLIST IS NOT NULL) OR (C_DELCUSTACOR.VRPRCUSTOAF IS NOT NULL) THEN
         IF V_IDUTCUSLIPR = 'S' THEN
            SELECT
               SUM(VRADIMPCOL) INTO V_VRIMPITM
            FROM
              IMPCOLET
            WHERE
              (CDFILIAL, NRCOLEPRECO, CDFORNECED,
               CDREGIAO, CDPRODUTO, CDMARCA) IN
              (SELECT
                  CUSTOSUP.CDFILCOTACOR, CUSTOSUP.NRCOLEPRACOR, CUSTOSUP.CDFORNECACOR,
                  CUSTOSUP.CDREGIAOACOR, CUSTOSUP.CDPRODACOR,   CUSTOSUP.CDMARCAACOR
               FROM
                  CUSTOSUP
               WHERE
                  CUSTOSUP.CDFILIAL   = C_DELCUSTACOR.CDFILIAL  AND
                  CUSTOSUP.CDPRODUTO  = C_DELCUSTACOR.CDPRODUTO AND
                  CUSTOSUP.DTCUSTOSUP = C_DELCUSTACOR.DTCUSTOSUP);
         END IF;
         IF V_IDUTCUSLIPR = 'S' THEN
            SELECT
               NVL(MAX(VRFATOCONV), 1)
            INTO
               V_VRFATOCONV
            FROM
               PRODUTO
            WHERE
               CDPRODUTO = C_DELCUSTACOR.CDPRODACOR;
         END IF;

         UPDATE CUSTOSUP
         SET
           VRCUSPRLISTP = DECODE(C_DELCUSTACOR.NRCOLEPRLIST, NULL, NULL, CUSTOSUP.VRHISPRLISTP),
           VRCUSPRLISM1 = NULL,
           VRCUSPRLISM2 = NULL,
           CDFILCOTACOR = NULL,
           NRCOLEPRACOR = NULL,
           CDMARCAACOR  = NULL,
           CDREGIAOACOR = NULL,
           CDFORNECACOR = NULL,
           CDPRODACOR   = NULL,
           VRCUSLIPRIMP = DECODE(V_IDUTCUSLIPR, 'N', NULL,DECODE(C_DELCUSTACOR.NRCOLEPRLIST, NULL, NULL, ((CUSTOSUP.VRHISPRLISTP*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV))
         WHERE
            (CDFILIAL   = C_DELCUSTACOR.CDFILIAL)  AND
            (CDPRODUTO  = C_DELCUSTACOR.CDPRODUTO) AND
            (DTCUSTOSUP = C_DELCUSTACOR.DTCUSTOSUP);

      ELSE

         DELETE CUSTOSUP
         WHERE
            (CDFILIAL   = C_DELCUSTACOR.CDFILIAL)   AND
            (CDPRODUTO  = C_DELCUSTACOR.CDPRODUTO)  AND
            (DTCUSTOSUP = C_DELCUSTACOR.DTCUSTOSUP) AND
            (VRPRCUSTOAF IS NULL);

      END IF;

      V_CONT_COMMIT := V_CONT_COMMIT + 1;
      IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
         V_CONT_COMMIT := 0;
         COMMIT;
      END IF;

   END LOOP;

   V_CONT_COMMIT := 0;

   /* Cursor: C_DELCUSTLIST

      Tratamento dos custos de lista de preos da qual a cotao de lista
      no mais existe. Os campos da cotao de lista sero limpos, mas se os campos
      de cotao de acordo e de custo de af no estiverem preenchidos, o registro
      ser excludo.
   */
   FOR C_DELCUSTLIST IN
     (SELECT
         CUSTOSUP.CDFILIAL,
         CUSTOSUP.CDPRODUTO,
         CUSTOSUP.DTCUSTOSUP,
         CUSTOSUP.NRCOLEPRACOR,
         CUSTOSUP.VRPRCUSTOAF
      FROM
         CUSTOSUP
      WHERE
         (CUSTOSUP.CDFILIAL   = NVL(P_CDFILCUSTO, CUSTOSUP.CDFILIAL)) AND
         (CUSTOSUP.DTCUSTOSUP >= V_DTINIVALLIST)                      AND
         (CUSTOSUP.CDFILCOTLIST IS NOT NULL)                          AND
         (CUSTOSUP.IDCUSLISTINF <> 'S')                               AND
         NOT EXISTS
           (SELECT
               NRCOLEPRECO
            FROM
               ITEMCOLE
            WHERE
               (ITEMCOLE.CDFILIAL    = CUSTOSUP.CDFILCOTLIST) AND
               (ITEMCOLE.NRCOLEPRECO = CUSTOSUP.NRCOLEPRLIST) AND
               (ITEMCOLE.CDMARCA     = CUSTOSUP.CDMARCALIST) AND
               (ITEMCOLE.CDREGIAO    = CUSTOSUP.CDREGIAOLIST) AND
               (ITEMCOLE.CDFORNECED  = CUSTOSUP.CDFORNECLIST) AND
               (ITEMCOLE.CDPRODUTO   = CUSTOSUP.CDPRODLIST) ) )

   LOOP
      IF (C_DELCUSTLIST.NRCOLEPRACOR IS NOT NULL) OR (C_DELCUSTLIST.VRPRCUSTOAF IS NOT NULL) THEN

         UPDATE CUSTOSUP
         SET
           VRHISPRLISTP = NULL,
           CDFILCOTLIST = NULL,
           NRCOLEPRLIST = NULL,
           CDMARCALIST  = NULL,
           CDREGIAOLIST = NULL,
           CDFORNECLIST = NULL,
           CDPRODLIST   = NULL
         WHERE
            (CDFILIAL   = C_DELCUSTLIST.CDFILIAL)  AND
            (CDPRODUTO  = C_DELCUSTLIST.CDPRODUTO) AND
            (DTCUSTOSUP = C_DELCUSTLIST.DTCUSTOSUP);

      ELSE

         DELETE CUSTOSUP
         WHERE
            (CDFILIAL   = C_DELCUSTLIST.CDFILIAL)   AND
            (CDPRODUTO  = C_DELCUSTLIST.CDPRODUTO)  AND
            (DTCUSTOSUP = C_DELCUSTLIST.DTCUSTOSUP) AND
            (VRPRCUSTOAF IS NULL);

      END IF;

      V_CONT_COMMIT := V_CONT_COMMIT + 1;
      IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
         V_CONT_COMMIT := 0;
         COMMIT;
      END IF;
   END LOOP;

   INSERT INTO CUSTOSUP_TMP
     (CDFILIAL,
      CDFILCENTCMP,
      NRSEQPRELIST,
      DTINIVALITM,
      DTFINVALITM,
      CDPRODESTO,
      NRCOLEPRECO,
      CDREGIAO,
      CDFORNECED,
      CDPRODUTO,
      CDMARCA,
      VRPRECOUN,
      VRPRECECO,
      VRPRECOPI)
   SELECT /*+ INDEX (ITEMCOLE CMP00289_FK) */
      FILIAL.CDFILIAL,
      P_CDFILIAL,
      P_NRSEQPRELIST,
      ITEMCOLE.DTINIVALITM,
      ITEMCOLE.DTFINVALITM,
      PRODUTO.CDPRODESTO,
      ITEMCOLE.NRCOLEPRECO,
            ITEMCOLE.CDREGIAO,
      ITEMCOLE.CDFORNECED,
      ITEMCOLE.CDPRODUTO,
      ITEMCOLE.CDMARCA,
      ITEMCOLE.VRPRECUNIITM/PRODUTO.VRFATOCONV AS VRPRECOUN,
      ITEMCOLE.VRPRECECOITM/PRODUTO.VRFATOCONV AS VRPRECECO,
      ITEMCOLE.VRPRECOITMPI/PRODUTO.VRFATOCONV AS VRPRECOPI
   FROM
      PRODUTO,
      FILIAL,
      ITEMCOLE
   WHERE
      (FILIAL.CDFILIAL       = NVL(P_CDFILCUSTO, FILIAL.CDFILIAL))       AND
      (ITEMCOLE.CDFILIAL     = P_CDFILIAL)                               AND
      (ITEMCOLE.NRSEQPRELIST = P_NRSEQPRELIST)                           AND
      (ITEMCOLE.IDITMLISPREC = 'S')                                      AND
      (ITEMCOLE.CDREGIAO     = FILIAL.CDREGIAO)                          AND
      (PRODUTO.CDPRODUTO     = ITEMCOLE.CDPRODUTO);

   COMMIT;

   V_CONT_COMMIT := 0;

   FOR C_CUSTO IN
     (SELECT
         CUSTOSUP_TMP.CDFILIAL,
         CUSTOSUP_TMP.DTINIVALITM,
         CUSTOSUP_TMP.DTFINVALITM,
         CUSTOSUP_TMP.CDPRODESTO,
         MIN(TO_CHAR(DECODE(V_IDTIPOAPUR, NULL, CUSTOSUP_TMP.VRPRECOUN,
                                           '1', CUSTOSUP_TMP.VRPRECECO,
                                                CUSTOSUP_TMP.VRPRECOPI) * V_MULTIPLO, V_MASCARA) ||'#'||
             TO_CHAR(CUSTOSUP_TMP.VRPRECOUN * V_MULTIPLO, V_MASCARA)  ||'%'||
             CUSTOSUP_TMP.NRCOLEPRECO ||
             CUSTOSUP_TMP.CDREGIAO    ||
             CUSTOSUP_TMP.CDPRODUTO   ||
             CUSTOSUP_TMP.CDMARCA     ||
             CUSTOSUP_TMP.CDFORNECED) AS MINPRECO
      FROM
         FORNECEDOR,
         PRODPREFMED,
         COLETAPR,
         CUSTOSUP_TMP
      WHERE
             (COLETAPR.CDFILIAL         = P_CDFILIAL)
         AND (COLETAPR.NRCOLEPRECO      = CUSTOSUP_TMP.NRCOLEPRECO)
         AND (PRODPREFMED.CDFILIAL (+)  = CUSTOSUP_TMP.CDFILIAL)
         AND (PRODPREFMED.CDPRODUTO (+) = CUSTOSUP_TMP.CDPRODESTO)
         AND (CUSTOSUP_TMP.CDPRODUTO    = NVL(PRODPREFMED.CDPRODPREF, CUSTOSUP_TMP.CDPRODUTO))
         AND (FORNECEDOR.CDFORNECED     = CUSTOSUP_TMP.CDFORNECED)
         AND (FORNECEDOR.IDSITUCADA     = 'A')
         AND (NVL(FORNECEDOR.IDTIPOFORN, 'N') <> 'A')

         AND NOT EXISTS (SELECT
                            CDFILIAL
                         FROM
                            REFORFIL
                         WHERE
                            (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)   AND
                            (CDFORNECED = CUSTOSUP_TMP.CDFORNECED) AND
                            (CDPERIENTR IS NULL))

         AND NOT EXISTS (SELECT
                            REFOREG.CDREGIAO
                         FROM
                            REFOREG
                         WHERE
                            (REFOREG.CDREGIAO   = CUSTOSUP_TMP.CDREGIAO) AND
                            (REFOREG.CDFORNECED = CUSTOSUP_TMP.CDFORNECED))

         AND NOT EXISTS (SELECT
                            QFOPRODFORN.CDPRODUTO
                         FROM
                            QFOPRODFORN,
                            PARASUPRI
                         WHERE
                            (PARASUPRI.CDFILIAL     = P_CDFILIAL)              AND
                            (QFOPRODFORN.CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO)  AND
                            (QFOPRODFORN.CDFORNECED = CUSTOSUP_TMP.CDFORNECED) AND
                            ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOPRODFORN.DTVALPRFORN)))))

         AND NOT EXISTS (SELECT
                            QFOMARPROD.CDMARCA
                         FROM
                            QFOMARPROD,
                            PARASUPRI
                         WHERE
                            (PARASUPRI.CDFILIAL   = P_CDFILIAL)             AND
                            (QFOMARPROD.CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                            (QFOMARPROD.CDMARCA   = CUSTOSUP_TMP.CDMARCA)   AND
                            ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOMARPROD.DTVALAPROVA)))))

         AND EXISTS (SELECT
                        QFOMARPROD.CDMARCA
                     FROM
                        QFOMARPROD
                     WHERE
                        (QFOMARPROD.CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                        (QFOMARPROD.CDMARCA   = CUSTOSUP_TMP.CDMARCA)

                     UNION

                     SELECT
                        PARASUPRI.CDMARCA
                     FROM
                        PARASUPRI
                     WHERE
                        (PARASUPRI.CDFILIAL    = P_CDFILIAL) AND
                        (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))

         AND NOT EXISTS (SELECT
                            QUALIFICACAO.CDQUALIF
                         FROM
                            QUALIFICACAO,
                            PARASUPRI
                         WHERE
                            (QUALIFICACAO.CDQUALIF     = FORNECEDOR.CDQUALIF) AND
                            (PARASUPRI.CDFILIAL        = P_CDFILIAL)          AND
                            (FORNECEDOR.IDFORNAUTO     = 'N')                 AND
                            ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > FORNECEDOR.DTVALQUALIF) OR (PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))

         AND (
                 (EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART = '1')                    AND
                             (CDMARCA   = CUSTOSUP_TMP.CDMARCA)))

              OR (EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART = '2')                    AND
                             (CDMARCA   = CUSTOSUP_TMP.CDMARCA)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL ) AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '4')                    AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '5')                    AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '7')                    AND
                             (CDMARCA    = CUSTOSUP_TMP.CDMARCA)   AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '8')                    AND
                             (CDMARCA    = CUSTOSUP_TMP.CDMARCA)   AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDPRODUTO
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  IN ('3','6','9'))))

              OR (NOT EXISTS (SELECT
                                 CDPRODUTO
                              FROM
                                 PARTFILI
                              WHERE
                                 (CDFILIAL  = CUSTOSUP_TMP.CDFILIAL) AND
                                 (CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO)))
              )

         AND (NOT EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART = '3')                    AND
                             (CDMARCA   = CUSTOSUP_TMP.CDMARCA)))

         AND (NOT EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '6')                    AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))

         AND (NOT EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTOSUP_TMP.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTOSUP_TMP.CDPRODUTO) AND
                             (CDTIPPART  = '9')                    AND
                             (CDMARCA    = CUSTOSUP_TMP.CDMARCA)   AND
                             (CDFORNECED = CUSTOSUP_TMP.CDFORNECED)))
      GROUP BY
         CUSTOSUP_TMP.CDFILIAL,
         CUSTOSUP_TMP.DTINIVALITM,
         CUSTOSUP_TMP.DTFINVALITM,
         CUSTOSUP_TMP.CDPRODESTO)
   LOOP
      V_POSMINPREPI := INSTR(C_CUSTO.MINPRECO, '#');
      V_POSMINPRECO := INSTR(C_CUSTO.MINPRECO, '%');

      V_MINPRECO    := (SUBSTR(C_CUSTO.MINPRECO, V_POSMINPREPI + 1, V_POSMINPRECO - V_POSMINPREPI - 1))/V_MULTIPLO;
      V_NRCOLEPRECO := SUBSTR(C_CUSTO.MINPRECO, V_POSMINPRECO+1, 10);
      V_CDREGIAO    := SUBSTR(C_CUSTO.MINPRECO, V_POSMINPRECO+11, 3);
      V_CDPRODUTO   := SUBSTR(C_CUSTO.MINPRECO, V_POSMINPRECO+14, 10);
      V_CDMARCA     := SUBSTR(C_CUSTO.MINPRECO, V_POSMINPRECO+24, 5);
      V_CDFORNECED  := SUBSTR(C_CUSTO.MINPRECO, V_POSMINPRECO+29, 21);

      IF V_IDUTCUSLIPR = 'S' THEN
         SELECT
            SUM(VRADIMPCOL) INTO V_VRIMPITM
         FROM
            IMPCOLET
         WHERE
            CDFILIAL    = P_CDFILIAL    AND
            NRCOLEPRECO = V_NRCOLEPRECO AND
            CDFORNECED  = V_CDFORNECED  AND
            CDREGIAO    = V_CDREGIAO    AND
            CDPRODUTO   = V_CDPRODUTO   AND
            CDMARCA     = V_CDMARCA;
      END IF;

      SELECT
         NVL(MAX(MOVINDICE.VRINDICE), 0) * NVL(V_MINPRECO, 0) INTO V_VRPRECULISM1
      FROM
         PARAMGERAL,
         MOVINDICE
      WHERE
         (PARAMGERAL.CDINDICEMF = MOVINDICE.CDINDICE)  AND
         (MOVINDICE.DTREFIND    = C_CUSTO.DTINIVALITM) AND
         (MOVINDICE.CDTPINDICE  = '1')                 AND
         (MOVINDICE.IDPERVALOR  = '2');

      SELECT
         NVL(MAX(MOVINDICE.VRINDICE), 0) * NVL(V_MINPRECO, 0) INTO V_VRPRECULISM2
      FROM
         PARAMGERAL,
         MOVINDICE
      WHERE
         (PARAMGERAL.CDINDICEMF2 = MOVINDICE.CDINDICE)  AND
         (MOVINDICE.DTREFIND     = C_CUSTO.DTINIVALITM) AND
         (MOVINDICE.CDTPINDICE   = '1') AND
         (MOVINDICE.IDPERVALOR   = '2');

/*######################### REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ######################################*/
      FOR C_CUSLISTINFLAC IN /*RETORNA OS CUSTOS DE LISTA INFLACIONADA ANTERIORES AO QUE ESTA SENDO GRAVADO*/
         (SELECT
             DTCUSTOSUP,
             DTFINCUSTSUP
          FROM
             CUSTOSUP
          WHERE
             CDFILIAL = C_CUSTO.CDFILIAL AND
             CDPRODUTO = C_CUSTO.CDPRODESTO AND
             IDCUSLISTINF = 'S' AND
             DTCUSTOSUP <= C_CUSTO.DTFINVALITM) LOOP
          IF C_CUSTO.DTFINVALITM + 1 > C_CUSLISTINFLAC.DTFINCUSTSUP THEN /*SE O CUSTO DA LISTA INFLACIONADA VAI SER EXCLUIDO OU NAO*/
             DELETE FROM CUSTOSUP
             WHERE
                CDFILIAL = C_CUSTO.CDFILIAL AND
                CDPRODUTO = C_CUSTO.CDPRODESTO AND
                DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                IDCUSLISTINF = 'S';
          ELSE
             UPDATE CUSTOSUP
             SET DTCUSTOSUP = C_CUSTO.DTFINVALITM + 1
             WHERE
                CDFILIAL = C_CUSTO.CDFILIAL AND
                CDPRODUTO = C_CUSTO.CDPRODESTO AND
                DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                IDCUSLISTINF = 'S';
          END IF;
      END LOOP;
/*######################### FIM DO REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ###############################*/

   /* O campo VRHISPRLISTP, no update abaixo, tem a funo de guardar o custo da lista,
      para o caso dele ser substitudo pelo preo de algum acordo existente, no processo
      que  executado mais abaixo. */
      IF V_IDUTCUSLIPR = 'S' THEN
         SELECT
            NVL(MAX(VRFATOCONV), 1)
         INTO
            V_VRFATOCONV
         FROM
            PRODUTO
         WHERE
            PRODUTO.CDPRODUTO = V_CDPRODUTO;
      END IF;      

      UPDATE CUSTOSUP SET
         VRCUSPRLISTP = V_MINPRECO,
         VRHISPRLISTP = V_MINPRECO,
         CDFILCOTLIST = P_CDFILIAL,
         NRCOLEPRLIST = V_NRCOLEPRECO,
         CDREGIAOLIST = V_CDREGIAO,
         CDFORNECLIST = V_CDFORNECED,
         CDPRODLIST   = V_CDPRODUTO,
         CDMARCALIST  = V_CDMARCA,
         DTFINCUSTSUP = C_CUSTO.DTFINVALITM,
         VRCUSPRLISM1 = V_VRPRECULISM1,
         VRCUSPRLISM2 = V_VRPRECULISM2,
         CDFILCOTACOR = NULL,
         NRCOLEPRACOR = NULL,
         CDMARCAACOR  = NULL,
         CDREGIAOACOR = NULL,
         CDFORNECACOR = NULL,
         CDPRODACOR   = NULL,
         VRCUSLIPRIMP = DECODE(V_IDUTCUSLIPR, 'N', NULL, ((V_MINPRECO*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV)
      WHERE
         (CDFILIAL   = C_CUSTO.CDFILIAL)   AND
         (CDPRODUTO  = C_CUSTO.CDPRODESTO) AND
         (DTCUSTOSUP = C_CUSTO.DTINIVALITM);

      IF SQL%NOTFOUND THEN
        INSERT INTO CUSTOSUP
          (CDFILIAL,
           CDPRODUTO,
           DTCUSTOSUP,
           VRCUSPRLISTP,
           CDFILCOTLIST,
           NRCOLEPRLIST,
           CDREGIAOLIST,
           CDFORNECLIST,
           CDPRODLIST,
           CDMARCALIST,
           VRCUSPRLISM1,
           VRCUSPRLISM2,
           VRHISPRLISTP,
           DTFINCUSTSUP,
           VRCUSLIPRIMP)
        VALUES
          (C_CUSTO.CDFILIAL,
           C_CUSTO.CDPRODESTO,
           C_CUSTO.DTINIVALITM,
           V_MINPRECO,
           P_CDFILIAL,
           V_NRCOLEPRECO,
           V_CDREGIAO,
           V_CDFORNECED,
           V_CDPRODUTO,
           V_CDMARCA,
           V_VRPRECULISM1,
           V_VRPRECULISM2,
           V_MINPRECO,
           C_CUSTO.DTFINVALITM,
           DECODE(V_IDUTCUSLIPR, 'N', NULL, ((V_MINPRECO*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV));

      END IF;

      V_CONT_COMMIT := V_CONT_COMMIT + 1;
      IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
        V_CONT_COMMIT := 0;
        COMMIT;
      END IF;

   END LOOP;

   INSERT INTO CUSTOSUPACOR_TMP
     (CDFILIAL,
      CDFILCENTCMP,
      NRSEQPRELIST,
      DTINIVALITM,
      DTFINVALITM,
      CDPRODESTO,
      NRCOLEPRECO,
      CDREGIAO,
      CDFORNECED,
      CDPRODUTO,
      CDMARCA,
      VRPRECOUN,
      VRPRECECO,
      VRPRECOPI)
   SELECT /*+ INDEX (ITEMCOLE PK_ITEMCOLE) */
      FILIAL.CDFILIAL,
      P_CDFILIAL,
      P_NRSEQPRELIST,
      ITEMCOLE.DTINIVALITM,
      ITEMCOLE.DTFINVALITM,
      PRODUTO.CDPRODESTO,
      ITEMCOLE.NRCOLEPRECO,
      ITEMCOLE.CDREGIAO,
      ITEMCOLE.CDFORNECED,
      PRODUTO.CDPRODUTO,
      ITEMCOLE.CDMARCA,
      ITEMCOLE.VRPRECUNIITM/PRODUTO.VRFATOCONV AS VRPRECOUN,
      ITEMCOLE.VRPRECECOITM/PRODUTO.VRFATOCONV AS VRPRECECO,
      ITEMCOLE.VRPRECOITMPI/PRODUTO.VRFATOCONV AS VRPRECOPI
   FROM
      PRODUTO,
      FILIAL,
      COLETAPR,
      ITEMCOLE,
      PARTFILI
   WHERE
      (FILIAL.CDFILIAL       = NVL(P_CDFILCUSTO, FILIAL.CDFILIAL)) AND
      (PARTFILI.CDFILIAL     = FILIAL.CDFILIAL)                    AND
      (PARTFILI.CDTIPPART    = '4')                                AND
      (PARTFILI.CDFILCOTA    = P_CDFILIAL)                         AND
      (ITEMCOLE.CDFILIAL     = P_CDFILIAL)                         AND
      (ITEMCOLE.NRCOLEPRECO  = PARTFILI.NRCOLEPRECO)               AND
      (ITEMCOLE.CDPRODUTO    = PARTFILI.CDPRODUTO)                 AND
      (ITEMCOLE.CDFORNECED   = PARTFILI.CDFORNECED)                AND
      (ITEMCOLE.CDREGIAO     = FILIAL.CDREGIAO)                    AND
      (ITEMCOLE.DTFINVALITM  > TRUNC(SYSDATE))                     AND
      (PRODUTO.CDPRODUTO     = ITEMCOLE.CDPRODUTO)                 AND
      (COLETAPR.CDFILIAL     = ITEMCOLE.CDFILIAL)                  AND
      (COLETAPR.NRCOLEPRECO  = ITEMCOLE.NRCOLEPRECO)               AND
      (COLETAPR.IDDISMONTLIS = 'N');

   COMMIT;

   V_CONT_COMMIT := 0;

   FOR C_ACORDO IN
     (SELECT  /*+ INDEX (PRODPREFMED PK_PRODPREFMED) */
         CUSTO.CDFILIAL,
         CUSTO.DTINIVALITM,
         CUSTO.DTFINVALITM,
         CUSTO.CDPRODESTO,
         MIN(TO_CHAR(DECODE(V_IDTIPOAPUR, NULL, CUSTO.VRPRECOUN,
                                           '1', CUSTO.VRPRECECO,
                                                CUSTO.VRPRECOPI) * V_MULTIPLO, V_MASCARA) ||'#'||
             TO_CHAR(CUSTO.VRPRECOUN * V_MULTIPLO, V_MASCARA)  ||'%'||
             CUSTO.NRCOLEPRECO ||
             CUSTO.CDREGIAO    ||
             CUSTO.CDPRODUTO   ||
             CUSTO.CDMARCA     ||
             CUSTO.CDFORNECED) AS MINPRECO
      FROM
         CUSTOSUPACOR_TMP CUSTO,
         PRODPREFMED,
         COLETAPR,
         FORNECEDOR
      WHERE
             (COLETAPR.CDFILIAL         = P_CDFILIAL)
         AND (COLETAPR.NRCOLEPRECO      = CUSTO.NRCOLEPRECO)
         AND (PRODPREFMED.CDFILIAL (+)  = CUSTO.CDFILIAL)
         AND (PRODPREFMED.CDPRODUTO (+) = CUSTO.CDPRODESTO)
         AND (CUSTO.CDPRODUTO           = NVL(PRODPREFMED.CDPRODPREF, CUSTO.CDPRODUTO))
         AND (FORNECEDOR.CDFORNECED     = CUSTO.CDFORNECED)
         AND (FORNECEDOR.IDSITUCADA     = 'A')
         AND (NVL(FORNECEDOR.IDTIPOFORN, 'N') <> 'A')

         AND NOT EXISTS (SELECT
                            CDFILIAL
                         FROM
                            REFORFIL
                         WHERE
                            (CDFILIAL   = CUSTO.CDFILIAL)   AND
                            (CDFORNECED = CUSTO.CDFORNECED) AND
                            (CDPERIENTR IS NULL))

         AND NOT EXISTS (SELECT
                            REFOREG.CDREGIAO
                         FROM
                            REFOREG
                         WHERE
                            (REFOREG.CDREGIAO   = CUSTO.CDREGIAO) AND
                            (REFOREG.CDFORNECED = CUSTO.CDFORNECED))

         AND NOT EXISTS (SELECT
                            QFOPRODFORN.CDPRODUTO
                         FROM
                            QFOPRODFORN,
                            PARASUPRI
                         WHERE
                            (PARASUPRI.CDFILIAL     = P_CDFILIAL)       AND
                            (QFOPRODFORN.CDPRODUTO  = CUSTO.CDPRODUTO)  AND
                            (QFOPRODFORN.CDFORNECED = CUSTO.CDFORNECED) AND
                            ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOPRODFORN.DTVALPRFORN)))))

         AND NOT EXISTS (SELECT
                            QFOMARPROD.CDMARCA
                         FROM
                            QFOMARPROD,
                            PARASUPRI
                         WHERE
                            (PARASUPRI.CDFILIAL   = P_CDFILIAL)      AND
                            (QFOMARPROD.CDPRODUTO = CUSTO.CDPRODUTO) AND
                            (QFOMARPROD.CDMARCA   = CUSTO.CDMARCA)   AND
                            ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND COLETAPR.DTCOLEPREC > QFOMARPROD.DTVALAPROVA)))))

         AND EXISTS (SELECT
                        QFOMARPROD.CDMARCA
                     FROM
                        QFOMARPROD
                     WHERE
                        (QFOMARPROD.CDPRODUTO = CUSTO.CDPRODUTO) AND
                        (QFOMARPROD.CDMARCA   = CUSTO.CDMARCA)

                     UNION

                     SELECT
                        PARASUPRI.CDMARCA
                     FROM
                        PARASUPRI
                     WHERE
                        (PARASUPRI.CDFILIAL    = P_CDFILIAL) AND
                        (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL))

         AND NOT EXISTS (SELECT
                            QUALIFICACAO.CDQUALIF
                         FROM
                            QUALIFICACAO,
                            PARASUPRI
                         WHERE
                            (QUALIFICACAO.CDQUALIF     = FORNECEDOR.CDQUALIF) AND
                            (PARASUPRI.CDFILIAL        = P_CDFILIAL)          AND
                            (FORNECEDOR.IDFORNAUTO     = 'N')                 AND
                            ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ  = 'D' AND COLETAPR.DTCOLEPREC > FORNECEDOR.DTVALQUALIF) OR (PARASUPRI.IDULTIDTVALQ = 'M' AND COLETAPR.DTCOLEPREC > LAST_DAY(FORNECEDOR.DTVALQUALIF)))))

         AND (
                 (EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO = CUSTO.CDPRODUTO) AND
                             (CDTIPPART = '1')             AND
                             (CDMARCA   = CUSTO.CDMARCA)))

              OR (EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO = CUSTO.CDPRODUTO) AND
                             (CDTIPPART = '2')             AND
                             (CDMARCA   = CUSTO.CDMARCA)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL ) AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '4')             AND
                             (CDFORNECED = CUSTO.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '5')             AND
                             (CDFORNECED = CUSTO.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '7')             AND
                             (CDMARCA    = CUSTO.CDMARCA)   AND
                             (CDFORNECED = CUSTO.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '8')             AND
                             (CDMARCA    = CUSTO.CDMARCA)   AND
                             (CDFORNECED = CUSTO.CDFORNECED)))

              OR (EXISTS (SELECT
                             CDPRODUTO
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO = CUSTO.CDPRODUTO) AND
                             (CDTIPPART IN ('3','6','9'))))

              OR (NOT EXISTS (SELECT
                             CDPRODUTO
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTO.CDFILIAL) AND
                             (CDPRODUTO = CUSTO.CDPRODUTO)))
              )
         AND (NOT EXISTS (SELECT
                             CDMARCA
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL  = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO = CUSTO.CDPRODUTO) AND
                             (CDTIPPART = '3')             AND
                             (CDMARCA   = CUSTO.CDMARCA)))

         AND (NOT EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '6')             AND
                             (CDFORNECED = CUSTO.CDFORNECED)))

         AND (NOT EXISTS (SELECT
                             CDFORNECED
                          FROM
                             PARTFILI
                          WHERE
                             (CDFILIAL   = CUSTO.CDFILIAL)  AND
                             (CDPRODUTO  = CUSTO.CDPRODUTO) AND
                             (CDTIPPART  = '9')             AND
                             (CDMARCA    = CUSTO.CDMARCA)   AND
                             (CDFORNECED = CUSTO.CDFORNECED)))
      GROUP BY
         CUSTO.CDFILIAL,
         CUSTO.DTINIVALITM,
         CUSTO.DTFINVALITM,
         CUSTO.CDPRODESTO)
   LOOP
      V_POSMINPREPI := INSTR(C_ACORDO.MINPRECO, '#');
      V_POSMINPRECO := INSTR(C_ACORDO.MINPRECO, '%');

      V_MINPRECO    := (SUBSTR(C_ACORDO.MINPRECO, V_POSMINPREPI + 1, V_POSMINPRECO - V_POSMINPREPI - 1))/V_MULTIPLO;
      V_NRCOLEPRECO := SUBSTR(C_ACORDO.MINPRECO, V_POSMINPRECO+1, 10);
      V_CDREGIAO    := SUBSTR(C_ACORDO.MINPRECO, V_POSMINPRECO+11, 3);
      V_CDPRODUTO   := SUBSTR(C_ACORDO.MINPRECO, V_POSMINPRECO+14, 10);
      V_CDMARCA     := SUBSTR(C_ACORDO.MINPRECO, V_POSMINPRECO+24, 5);
      V_CDFORNECED  := SUBSTR(C_ACORDO.MINPRECO, V_POSMINPRECO+29, 21);

      IF V_IDUTCUSLIPR = 'S' THEN
         SELECT
            SUM(VRADIMPCOL) INTO V_VRIMPITM
         FROM
            IMPCOLET
         WHERE
            CDFILIAL    = P_CDFILIAL    AND
            NRCOLEPRECO = V_NRCOLEPRECO AND
            CDFORNECED  = V_CDFORNECED  AND
            CDREGIAO    = V_CDREGIAO    AND
            CDPRODUTO   = V_CDPRODUTO   AND
            CDMARCA     = V_CDMARCA;
      END IF;

      BEGIN

         SELECT
            NVL(MAX(MOVINDICE.VRINDICE), 0) * NVL(V_MINPRECO, 0) INTO V_VRPRECULISM1
         FROM
            PARAMGERAL,
            MOVINDICE
         WHERE
            (PARAMGERAL.CDINDICEMF = MOVINDICE.CDINDICE)   AND
            (MOVINDICE.DTREFIND    = C_ACORDO.DTINIVALITM) AND
            (MOVINDICE.CDTPINDICE  = '1')                  AND
            (MOVINDICE.IDPERVALOR  = '2');

         SELECT
            NVL(MAX(MOVINDICE.VRINDICE), 0) * NVL(V_MINPRECO, 0) INTO V_VRPRECULISM2
         FROM
            PARAMGERAL,
            MOVINDICE
         WHERE
            (PARAMGERAL.CDINDICEMF2 = MOVINDICE.CDINDICE)   AND
            (MOVINDICE.DTREFIND     = C_ACORDO.DTINIVALITM) AND
            (MOVINDICE.CDTPINDICE   = '1')                  AND
            (MOVINDICE.IDPERVALOR   = '2');

/*######################### REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ######################################*/
         FOR C_CUSLISTINFLAC IN /*RETORNA OS CUSTOS DE LISTA INFLACIONADA ANTERIORES AO QUE ESTA SENDO GRAVADO*/
            (SELECT
                DTCUSTOSUP,
                DTFINCUSTSUP
             FROM
                CUSTOSUP
             WHERE
                CDFILIAL = C_ACORDO.CDFILIAL AND
                CDPRODUTO = C_ACORDO.CDPRODESTO AND
                IDCUSLISTINF = 'S' AND
                DTCUSTOSUP <= C_ACORDO.DTFINVALITM) LOOP
             IF C_ACORDO.DTFINVALITM + 1 > C_CUSLISTINFLAC.DTFINCUSTSUP THEN /*SE O CUSTO DA LISTA INFLACIONADA VAI SER EXCLUIDO OU NAO*/
                DELETE FROM CUSTOSUP
                WHERE
                   CDFILIAL = C_ACORDO.CDFILIAL AND
                   CDPRODUTO = C_ACORDO.CDPRODESTO AND
                   DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                   IDCUSLISTINF = 'S';
             ELSE
                UPDATE CUSTOSUP
                SET DTCUSTOSUP = C_ACORDO.DTFINVALITM + 1
                WHERE
                   CDFILIAL = C_ACORDO.CDFILIAL AND
                   CDPRODUTO = C_ACORDO.CDPRODESTO AND
                   DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                   IDCUSLISTINF = 'S';
             END IF;
         END LOOP;
/*######################### FIM DO REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ###############################*/
         IF V_IDUTCUSLIPR = 'S' THEN
            SELECT
               NVL(MAX(VRFATOCONV), 1)
            INTO
               V_VRFATOCONV
            FROM
               PRODUTO
            WHERE
               PRODUTO.CDPRODUTO = V_CDPRODUTO;
         END IF;      

         INSERT INTO CUSTOSUP
           (CDFILIAL,
            CDPRODUTO,
            DTCUSTOSUP,
            VRCUSPRLISTP,
            CDFILCOTACOR,
            NRCOLEPRACOR,
            CDREGIAOACOR,
            CDFORNECACOR,
            CDPRODACOR,
            CDMARCAACOR,
            VRCUSPRLISM1,
            VRCUSPRLISM2,
            DTFINCUSTSUP,
            VRCUSLIPRIMP)
         VALUES
           (C_ACORDO.CDFILIAL,
            C_ACORDO.CDPRODESTO,
            C_ACORDO.DTINIVALITM,
            V_MINPRECO,
            P_CDFILIAL,
            V_NRCOLEPRECO,
            V_CDREGIAO,
            V_CDFORNECED,
            V_CDPRODUTO,
            V_CDMARCA,
            V_VRPRECULISM1,
            V_VRPRECULISM2,
            C_ACORDO.DTFINVALITM,
            DECODE(V_IDUTCUSLIPR, 'N', NULL, ((V_MINPRECO*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV));

      EXCEPTION
         WHEN DUP_VAL_ON_INDEX THEN BEGIN

            /* Deletando custo imediatamente posterior ao do acordo */
            DELETE FROM CUSTOSUP
            WHERE
               (CDFILIAL   = C_ACORDO.CDFILIAL)   AND
               (CDPRODUTO  = C_ACORDO.CDPRODESTO) AND
               (DTCUSTOSUP = C_ACORDO.DTFINVALITM + 1);

            /* Caso j exista um custo de lista de preos com data de
               inicio igual ao custo de acordo e com a data final maior,
               ou seja, se o custo de acordo estiver dentro do perodo de
               uma lista, ento o custo de lista passar a ter a data
               de incio um dia depois da data final do custo de acordo */

            FOR C_CUSTOPOST IN
               (SELECT
                   CUSTOSUP.CDFILIAL,
                   CUSTOSUP.CDPRODUTO,
                   C_ACORDO.DTFINVALITM + 1 AS DTCUSTOSUP,
                   CUSTOSUP.VRCUSPRLISTP,
                   CUSTOSUP.CDFILCOTLIST,
                   CUSTOSUP.NRCOLEPRLIST,
                   CUSTOSUP.CDREGIAOLIST,
                   CUSTOSUP.CDFORNECLIST,
                   CUSTOSUP.CDPRODLIST,
                   CUSTOSUP.CDMARCALIST,
                   CUSTOSUP.VRCUSPRLISM1,
                   CUSTOSUP.VRCUSPRLISM2,
                   CUSTOSUP.VRHISPRLISTP,
                   PREVLISTA.DTFINVALLIST
                FROM
                   CUSTOSUP,
                   PREVLISTA
                WHERE
                   (CUSTOSUP.CDFILIAL      = C_ACORDO.CDFILIAL)    AND
                   (CUSTOSUP.CDPRODUTO     = C_ACORDO.CDPRODESTO)  AND
                   (CUSTOSUP.DTCUSTOSUP    = C_ACORDO.DTINIVALITM) AND
                   (PREVLISTA.CDFILIAL     = P_CDFILIAL)           AND
                   (PREVLISTA.NRSEQPRELIST = P_NRSEQPRELIST)       AND
                   (PREVLISTA.DTINIVALLIST = C_ACORDO.DTINIVALITM) AND
                   (PREVLISTA.DTFINVALLIST > C_ACORDO.DTFINVALITM)) LOOP
/*######################### REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ######################################*/
               FOR C_CUSLISTINFLAC IN /*RETORNA OS CUSTOS DE LISTA INFLACIONADA ANTERIORES AO QUE ESTA SENDO GRAVADO*/
                  (SELECT
                      DTCUSTOSUP,
                      DTFINCUSTSUP
                   FROM
                      CUSTOSUP
                   WHERE
                      CDFILIAL = C_CUSTOPOST.CDFILIAL AND
                      CDPRODUTO = C_CUSTOPOST.CDPRODUTO AND
                      IDCUSLISTINF = 'S' AND
                      DTCUSTOSUP <= C_CUSTOPOST.DTFINVALLIST) LOOP
                   IF C_CUSTOPOST.DTFINVALLIST + 1 > C_CUSLISTINFLAC.DTFINCUSTSUP THEN /*SE O CUSTO DA LISTA INFLACIONADA VAI SER EXCLUIDO OU NAO*/
                      DELETE FROM CUSTOSUP
                      WHERE
                         CDFILIAL = C_CUSTOPOST.CDFILIAL AND
                         CDPRODUTO = C_CUSTOPOST.CDPRODUTO AND
                         DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                         IDCUSLISTINF = 'S';
                   ELSE
                      UPDATE CUSTOSUP
                      SET DTCUSTOSUP = C_CUSTOPOST.DTFINVALLIST + 1
                      WHERE
                         CDFILIAL = C_CUSTOPOST.CDFILIAL AND
                         CDPRODUTO = C_CUSTOPOST.CDPRODUTO AND
                         DTCUSTOSUP = C_CUSLISTINFLAC.DTCUSTOSUP AND
                         IDCUSLISTINF = 'S';
                   END IF;
               END LOOP;
/*######################### FIM DO REMANEJAMENTO DO CUSTO DA LISTA INFLACIONADA ###############################*/
               SELECT
                  SUM(VRADIMPCOL) INTO V_VRIMPITM
               FROM
                  IMPCOLET
               WHERE
                  CDFILIAL    = C_CUSTOPOST.CDFILCOTLIST AND
                  NRCOLEPRECO = C_CUSTOPOST.NRCOLEPRLIST AND
                  CDFORNECED  = C_CUSTOPOST.CDFORNECLIST AND
                  CDREGIAO    = C_CUSTOPOST.CDREGIAOLIST AND
                  CDPRODUTO   = C_CUSTOPOST.CDPRODLIST   AND
                  CDMARCA     = C_CUSTOPOST.CDMARCALIST  AND
                  V_IDUTCUSLIPR = 'S';

               IF V_IDUTCUSLIPR = 'S' THEN
                  SELECT
                     NVL(MAX(VRFATOCONV), 1)
                  INTO
                     V_VRFATOCONV
                  FROM
                     PRODUTO
                  WHERE
                     PRODUTO.CDPRODUTO = C_CUSTOPOST.CDPRODLIST;
               END IF;      

               INSERT INTO CUSTOSUP
                 (CDFILIAL,
                  CDPRODUTO,
                  DTCUSTOSUP,
                  VRCUSPRLISTP,
                  CDFILCOTLIST,
                  NRCOLEPRLIST,
                  CDREGIAOLIST,
                  CDFORNECLIST,
                  CDPRODLIST,
                  CDMARCALIST,
                  VRCUSPRLISM1,
                  VRCUSPRLISM2,
                  VRHISPRLISTP,
                  DTFINCUSTSUP,
                  VRCUSLIPRIMP)
                  VALUES
                  (C_CUSTOPOST.CDFILIAL,
                   C_CUSTOPOST.CDPRODUTO,
                   C_CUSTOPOST.DTCUSTOSUP,
                   C_CUSTOPOST.VRCUSPRLISTP,
                   C_CUSTOPOST.CDFILCOTLIST,
                   C_CUSTOPOST.NRCOLEPRLIST,
                   C_CUSTOPOST.CDREGIAOLIST,
                   C_CUSTOPOST.CDFORNECLIST,
                   C_CUSTOPOST.CDPRODLIST,
                   C_CUSTOPOST.CDMARCALIST,
                   C_CUSTOPOST.VRCUSPRLISM1,
                   C_CUSTOPOST.VRCUSPRLISM2,
                   C_CUSTOPOST.VRHISPRLISTP,
                   C_CUSTOPOST.DTFINVALLIST,
                   DECODE(V_IDUTCUSLIPR, 'N', NULL, ((C_CUSTOPOST.VRCUSPRLISTP*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV));
            END LOOP;

            IF V_IDUTCUSLIPR = 'S' THEN
               SELECT
                  SUM(VRADIMPCOL) INTO V_VRIMPITM
               FROM
                  IMPCOLET
               WHERE
                  CDFILIAL    = P_CDFILIAL    AND
                  NRCOLEPRECO = V_NRCOLEPRECO AND
                  CDFORNECED  = V_CDFORNECED  AND
                  CDREGIAO    = V_CDREGIAO    AND
                  CDPRODUTO   = V_CDPRODUTO   AND
                  CDMARCA     = V_CDMARCA;
            END IF;

            /* Atualizando custo de acordo */

            IF V_IDUTCUSLIPR = 'S' THEN
               SELECT
                  NVL(MAX(VRFATOCONV), 1)
               INTO
                  V_VRFATOCONV
               FROM
                  PRODUTO
               WHERE
                  PRODUTO.CDPRODUTO = V_CDPRODUTO;
            END IF;      

            UPDATE CUSTOSUP SET
               VRCUSPRLISTP = V_MINPRECO,
               CDFILCOTACOR = P_CDFILIAL,
               NRCOLEPRACOR = V_NRCOLEPRECO,
               CDREGIAOACOR = V_CDREGIAO,
               CDFORNECACOR = V_CDFORNECED,
               CDPRODACOR   = V_CDPRODUTO,
               CDMARCAACOR  = V_CDMARCA,
               DTFINCUSTSUP = C_ACORDO.DTFINVALITM,
               VRCUSPRLISM1 = V_VRPRECULISM1,
               VRCUSPRLISM2 = V_VRPRECULISM2,
               VRCUSLIPRIMP = DECODE(V_IDUTCUSLIPR, 'N', NULL, ((V_MINPRECO*V_VRFATOCONV) + V_VRIMPITM)/V_VRFATOCONV)
            WHERE
               (CDFILIAL   = C_ACORDO.CDFILIAL)   AND
               (CDPRODUTO  = C_ACORDO.CDPRODESTO) AND
               (DTCUSTOSUP = C_ACORDO.DTINIVALITM);
         END;
      END;

      /* Update e Insert a seguir:
         Faz o tratamento dos custos de lista de preos que esto dentro
         do perodo de validade da cotao de acordo: esses custos so
         excludos pois o custo vlido deve ser o custo do acordo.
      */

      UPDATE CUSTOSUP
      SET
         VRHISPRLISTP = NULL,
         VRCUSPRLISTP = NULL,
         VRCUSPRLISM1 = NULL,
         VRCUSPRLISM2 = NULL,
         CDFILCOTLIST = NULL,
         NRCOLEPRLIST = NULL,
         CDMARCALIST  = NULL,
         CDREGIAOLIST = NULL,
         CDFORNECLIST = NULL,
         CDPRODLIST   = NULL
      WHERE
         (CDFILIAL   = C_ACORDO.CDFILIAL)    AND
         (CDPRODUTO  = C_ACORDO.CDPRODESTO)  AND
         (DTCUSTOSUP > C_ACORDO.DTINIVALITM) AND
         (DTCUSTOSUP < C_ACORDO.DTFINVALITM) AND
         (VRPRCUSTOAF IS NOT NULL);

      DELETE CUSTOSUP
      WHERE
         (CDFILIAL   = C_ACORDO.CDFILIAL)    AND
         (CDPRODUTO  = C_ACORDO.CDPRODESTO)  AND
         (DTCUSTOSUP > C_ACORDO.DTINIVALITM) AND
         (DTCUSTOSUP < C_ACORDO.DTFINVALITM) AND
         (VRPRCUSTOAF IS NULL);

      V_CONT_COMMIT := V_CONT_COMMIT + 1;
      IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
         V_CONT_COMMIT := 0;
         COMMIT;
      END IF;
   END LOOP;
   COMMIT;
END;
/


-- VERSAO --
BEGIN ATUVEROBJ('LISPREC_UPPRODFILI','4.05.136'); END;
/

